# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-01-11 07:54
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_mission', '0015_auto_20181219_2057'),
    ]

    operations = [
        migrations.AddField(
            model_name='userstage',
            name='token',
            field=models.CharField(max_length=180, null=True, verbose_name='\u76f8\u540c\u4e00\u7c7b\u9636\u6bb5\u4efb\u52a1\u7684token'),
        ),
    ]
